@@ -92,6 +92,11 @@ module Cri
     #   command (ignored for commands with subcommands)
     attr_accessor :block
 
+    # @return [Boolean] true if the command should skip option parsing and
+    # treat all options as arguments.
+    attr_accessor :all_opts_as_args
+    alias all_opts_as_args? all_opts_as_args
+
     # Creates a new command using the DSL. If a string is given, the command
     # will be defined using the string; if a block is given, the block will be
     # used instead.
@@ -233,11 +238,11 @@ module Cri
       commands = commands_named(name)
 
       if commands.empty?
-        $stderr.puts "#{self.name}: unknown command '#{name}'\n"
+        warn "#{self.name}: unknown command '#{name}'\n"
         raise CriExitException.new(is_error: true)
       elsif commands.size > 1
-        $stderr.puts "#{self.name}: '#{name}' is ambiguous:"
-        $stderr.puts "  #{commands.map(&:name).sort.join(' ')}"
+        warn "#{self.name}: '#{name}' is ambiguous:"
+        warn "  #{commands.map(&:name).sort.join(' ')}"
         raise CriExitException.new(is_error: true)
       else
         commands[0]
@@ -271,7 +276,7 @@ module Cri
           if default_subcommand_name
             subcmd_name = default_subcommand_name
           else
-            $stderr.puts "#{name}: no command given"
+            warn "#{name}: no command given"
             raise CriExitException.new(is_error: true)
           end
         end
@@ -299,17 +304,22 @@ module Cri
     #
     # @return [void]
     def run_this(opts_and_args, parent_opts = {})
-      # Parse
-      parser = Cri::OptionParser.new(
-        opts_and_args, global_option_definitions
-      )
-      handle_parser_errors_while { parser.run }
-      local_opts  = parser.options
-      global_opts = parent_opts.merge(parser.options)
-      args = parser.arguments
+      if all_opts_as_args?
+        args = opts_and_args
+        global_opts = parent_opts
+      else
+        # Parse
+        parser = Cri::OptionParser.new(
+          opts_and_args, global_option_definitions
+        )
+        handle_parser_errors_while { parser.run }
+        local_opts  = parser.options
+        global_opts = parent_opts.merge(parser.options)
+        args = parser.arguments
 
-      # Handle options
-      handle_options(local_opts)
+        # Handle options
+        handle_options(local_opts)
+      end
 
       # Execute
       if block.nil?
@@ -352,6 +362,8 @@ module Cri
     end
 
     def partition(opts_and_args)
+      return [{}, opts_and_args.first, opts_and_args] if all_opts_as_args?
+
       # Parse
       delegate = Cri::Command::OptionParserPartitioningDelegate.new
       parser = Cri::OptionParser.new(opts_and_args, global_option_definitions)
@@ -369,10 +381,10 @@ module Cri
     def handle_parser_errors_while
       yield
     rescue Cri::OptionParser::IllegalOptionError => e
-      $stderr.puts "#{name}: illegal option -- #{e}"
+      warn "#{name}: illegal option -- #{e}"
       raise CriExitException.new(is_error: true)
     rescue Cri::OptionParser::OptionRequiresAnArgumentError => e
-      $stderr.puts "#{name}: option requires an argument -- #{e}"
+      warn "#{name}: option requires an argument -- #{e}"
       raise CriExitException.new(is_error: true)
     end
   end
