@@ -1,7 +1,5 @@
-# encoding: utf-8
-
 module Cri
-  # Cri::OptionParser is used for parsing commandline options.
+  # Cri::OptionParser is used for parsing command-line options.
   #
   # Option definitions are hashes with the keys `:short`, `:long` and
   # `:argument` (optionally `:description` but this is not used by the
@@ -19,7 +17,7 @@ module Cri
   #       { :short => 'p', :long => 'port', :argument => :required, :multiple => false },
   #     ]
   #
-  # For example, the following commandline options (which should not be
+  # For example, the following command-line options (which should not be
   # passed as a string, but as an array of strings):
   #
   #     foo -xyz -a hiss -s -m please --level 50 --father=ani -n luke squeak
@@ -92,11 +90,11 @@ module Cri
     # @return [Array] The not yet parsed options and arguments.
     attr_reader :unprocessed_arguments_and_options
 
-    # Parses the commandline arguments. See the instance `parse` method for
+    # Parses the command-line arguments. See the instance `parse` method for
     # details.
     #
     # @param [Array<String>] arguments_and_options An array containing the
-    #   commandline arguments (will probably be `ARGS` for a root command)
+    #   command-line arguments (will probably be `ARGS` for a root command)
     #
     # @param [Array<Hash>] definitions An array of option definitions
     #
@@ -108,7 +106,7 @@ module Cri
     # Creates a new parser with the given options/arguments and definitions.
     #
     # @param [Array<String>] arguments_and_options An array containing the
-    #   commandline arguments (will probably be `ARGS` for a root command)
+    #   command-line arguments (will probably be `ARGS` for a root command)
     #
     # @param [Array<Hash>] definitions An array of option definitions
     def initialize(arguments_and_options, definitions)
@@ -146,7 +144,7 @@ module Cri
       @running = false
     end
 
-    # Parses the commandline arguments into options and arguments.
+    # Parses the command-line arguments into options and arguments.
     #
     # During parsing, two errors can be raised:
     #
@@ -175,6 +173,9 @@ module Cri
           add_argument(e)
         end
       end
+
+      add_defaults
+
       self
     ensure
       @running = false
@@ -182,6 +183,10 @@ module Cri
 
     private
 
+    def add_defaults
+      @definitions.each { |d| add_default_option(d) }
+    end
+
     def handle_dashdash(e)
       add_argument(e)
       @no_more_options = true
@@ -199,9 +204,9 @@ module Cri
 
       # Find definition
       definition = @definitions.find { |d| d[:long] == option_key }
-      fail IllegalOptionError.new(option_key) if definition.nil?
+      raise IllegalOptionError.new(option_key) if definition.nil?
 
-      if [:required, :optional].include?(definition[:argument])
+      if %i[required optional].include?(definition[:argument])
         # Get option value if necessary
         if option_value.nil?
           option_value = find_option_value(definition, option_key)
@@ -223,12 +228,9 @@ module Cri
       option_keys.each do |option_key|
         # Find definition
         definition = @definitions.find { |d| d[:short] == option_key }
-        fail IllegalOptionError.new(option_key) if definition.nil?
+        raise IllegalOptionError.new(option_key) if definition.nil?
 
-        if option_keys.length > 1 && definition[:argument] == :required
-          # This is a combined option and it requires an argument, so complain
-          fail OptionRequiresAnArgumentError.new(option_key)
-        elsif [:required, :optional].include?(definition[:argument])
+        if %i[required optional].include?(definition[:argument])
           # Get option value
           option_value = find_option_value(definition, option_key)
 
@@ -244,8 +246,10 @@ module Cri
     def find_option_value(definition, option_key)
       option_value = @unprocessed_arguments_and_options.shift
       if option_value.nil? || option_value =~ /^-/
-        if definition[:argument] == :required
-          fail OptionRequiresAnArgumentError.new(option_key)
+        if definition[:argument] == :optional && definition[:default]
+          option_value = definition[:default]
+        elsif definition[:argument] == :required
+          raise OptionRequiresAnArgumentError.new(option_key)
         else
           @unprocessed_arguments_and_options.unshift(option_value)
           option_value = true
@@ -255,7 +259,8 @@ module Cri
     end
 
     def add_option(definition, value)
-      key = (definition[:long] || definition[:short]).to_sym
+      key = key_for(definition)
+
       if definition[:multiple]
         options[key] ||= []
         options[key] << value
@@ -266,10 +271,29 @@ module Cri
       delegate.option_added(key, value, self) unless delegate.nil?
     end
 
+    def add_default_option(definition)
+      key = key_for(definition)
+      return if options.key?(key)
+
+      value = definition[:default]
+      return unless value
+
+      if definition[:multiple]
+        options[key] ||= []
+        options[key] << value
+      else
+        options[key] = value
+      end
+    end
+
+    def key_for(definition)
+      (definition[:long] || definition[:short]).to_sym
+    end
+
     def add_argument(value)
       @raw_arguments << value
 
-      unless '--' == value
+      unless value == '--'
         delegate.argument_added(value, self) unless delegate.nil?
       end
     end
