@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 require 'colored'
 
 module Cri
@@ -21,7 +19,7 @@ module Cri
         end
       end
 
-      paragraphs.reject { |p| p.empty? }.map { |p| p.join(' ') }
+      paragraphs.reject(&:empty?).map { |p| p.join(' ') }
     end
 
     # Word-wraps and indents the string.
