@@ -1,8 +1,7 @@
-# encoding: utf-8
+require 'helper'
 
 module Cri
   class BaseTestCase < Cri::TestCase
-    def test_stub
-    end
+    def test_stub; end
   end
 end
