@@ -1,12 +1,12 @@
-# encoding: utf-8
+require 'helper'
 
 module Cri
   class CommandRunnerTestCase < Cri::TestCase
     def setup
       super
 
-      @options   = { :vehicle => 'pig' }
-      @arguments = %w( baby_monkey )
+      @options   = { vehicle: 'pig' }
+      @arguments = %w[baby_monkey]
       @command   = Cri::Command.new
     end
 
