@@ -1,4 +1,4 @@
-# encoding: utf-8
+require 'helper'
 
 module Cri
   class CoreExtTestCase < Cri::TestCase
